@@ -17,11 +17,10 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#include <config.h>
+#include "config.h" // krazy:exclude=includes
 
 #include <QLabel>
 #include <QVBoxLayout>
-#include <KDialog>
 #include <KLocalizedString>
 
 Config::Config(QWidget *parent)
@@ -35,28 +34,16 @@ void Config::ctorDone()
 	startedUp = true;
 }
 
-int Config::spacingHint()
-{
-	return KDialog::spacingHint() / 2;
-}
-
-int Config::marginHint()
-{
-	return KDialog::marginHint();
-}
-
 void Config::changed()
 {
 	if (startedUp)
-		emit modified();
+		emit modified(true);
 }
 
 MessageConfig::MessageConfig(const QString &text, QWidget *parent)
 	: Config(parent)
 {
 	QVBoxLayout *layout = new QVBoxLayout(this);
-        layout->setMargin( marginHint() );
-        layout->setSpacing( spacingHint() );
 	layout->addWidget(new QLabel(text, this));
 }
 
